@@ -15,4 +15,4 @@
 # ------------------------------------------------------------------------------
 
 from .SQLQuery import SQLQuery
-from .SQLQuery import RateLimitedException
+from .exceptions import RateLimitedException
